Home
=====

.. include:: generated/README.md
    :parser: myst_parser.sphinx_

.. toctree::
    :maxdepth: 1
    :hidden:

    self
    changelog

.. toctree::
    :maxdepth: 2
    :caption: Quick start
    :hidden:

    0. Try <quick_start/0.-try>
    1. Install <quick_start/1.-install>
    2. CLI <quick_start/2.-cli>
    3. API <quick_start/3.-api>

.. toctree::
    :maxdepth: 2
    :caption: Configuration
    :hidden:

    configuration/action_comments
    configuration/add_or_remove_imports
    configuration/black_compatibility
    Config files <configuration/config_files>
    configuration/custom_sections_and_ordering
    configuration/git_hook
    configuration/github_action
    configuration/multi_line_output_modes
    Options <configuration/options>
    Pre-commit <configuration/pre-commit>
    Profiles <configuration/profiles>

.. toctree::
    :maxdepth: 2
    :caption: How to guides
    :hidden:

    howto/shared_profiles

.. toctree::
    :maxdepth: 2
    :caption: Major releases
    :hidden:

    major_releases/introducing_isort_5
    Release policy <major_releases/release_policy>

.. toctree::
    :maxdepth: 2
    :caption: Upgrade guides
    :hidden:

    5.0.0 <upgrade_guides/5.0.0>

.. toctree::
    :maxdepth: 2
    :caption: Warning and Error codes
    :hidden:

    W0500 <warning_and_error_codes/W0500>

.. toctree::
    :maxdepth: 2
    :caption: Contributing
    :hidden:

    1. Contributing guide <contributing/1.-contributing-guide>
    2. Coding standard <contributing/2.-coding-standard>
    3. Code of conduct <contributing/3.-code-of-conduct>
    4. Acknowledgements <contributing/4.-acknowledgements>

.. toctree::
    :maxdepth: 1
    :caption: Reference
    :hidden:

    reference/isort
